Functions
- copy_
dir_ all - is_
supported_ format - Checks if a valid file has a supported filetype regardless of extension
using
infer::get_from_path(). Fallback uses the file extension if a file extension is known to be supported and the usual mime-type. - process_
globs - Taken from firstyear’s code in obs-service-cargo for libroast adoption/migration.